/**
 * @file
 * Vertical tabs responsive js file.
 */

(function ($) {
  Drupal.behaviors.vertical_tabs_responsive = {
    attach: function (context, settings) {
      var left;
      var vt_width;
      var content_width;

      try {
        left = Drupal.vertical_tabs_responsive.intToString(settings.vertical_tabs_responsive.left);
        vt_width = Drupal.vertical_tabs_responsive.intToString(settings.vertical_tabs_responsive.vt_width);
      }
      catch(err) {
        // Default values if something goes wrong.
        left = 0;
        vt_width = 30;
      }
      content_width = 100 - vt_width;

      if (!$('.vertical-tabs-panes').length) {
        // If there are no vertical tabs we reset content area to its initial state.
        $('body').find('#content').css({
          'width': 'initial',
          'margin-left': 'initial'
        });
      }
      else if (typeof left != 'undefined' && typeof content_width != 'undefined' && typeof vt_width != 'undefined') {
        // Change content and vertical tabs width depending on user's selection (desktop screens).
        var margin = 4;
        var vt_final = vt_width - margin;

        $('body').find('#content').css('width', content_width + '%');
        $('body').find('.vertical-tabs-panes').css('width', vt_final + '%');
        if(left == 1) {
          $('body').find('#content').css('margin-left', vt_width + '%');
        }
      }
    }
  };
})(jQuery);

/**
 * Attach utility functions.
 */
Drupal.vertical_tabs_responsive = Drupal.vertical_tabs_responsive || {};

/**
 * Converts string from drupal settings variable to integers.
 */
Drupal.vertical_tabs_responsive.intToString = function (configuration) {

  var str = String(configuration);

  // Erase first " character.
  str = str.replace('"', "");
  // Erase second " character.
  str = str.replace('"', "");

  return str;
};
